import { ApiError, getJavaUuid, getNoAuthUuid, UserNotFoundError } from '$lib/server/minecraft';
import { error, type RequestHandler } from '@sveltejs/kit';
import { Settings, User } from '$lib/server/database';
import { RegisterSchema } from './schema';

export const POST = (async ({ request }) => {
	// eslint-disable-next-line @typescript-eslint/ban-ts-comment
	// @ts-expect-error
	if ((await Settings.findOne({ where: { key: 'register.enabled' } }))?.value === false) {
		throw error(400, 'Anmeldung geschlossen');
	}

	try {
		var data = RegisterSchema.parse(await request.json());
	} catch (e) {
		console.error(e);
		throw error(400, 'Ungültige Parameter');
	}

	let uuid: string | null;
	try {
		switch (data.playertype) {
			case 'java':
				uuid = await getJavaUuid(data.username);
				break;
			case 'bedrock':
				uuid = null;
				// uuid = await getBedrockUuid(username);
				break;
			case 'noauth':
				uuid = getNoAuthUuid(data.username);
				break;
		}
	} catch (e) {
		if (e instanceof UserNotFoundError) {
			throw error(
				400,
				"Der Spielername '" +
					data.username +
					"' existiert nicht. Hast Du Deinen Spielernamen korrekt geschrieben " +
					'und besitzt Du einen Minecraft-Account?\n\nKontaktiere bitte einen Admin, falls Du Dich trotz korrekter ' +
					'Angabe nicht registrieren kannst.'
			);
		} else if (e instanceof ApiError) {
			console.error((e as Error).message);
			uuid = null;
		} else {
			console.error((e as Error).message);
			throw error(500);
		}
	}

	if (uuid && (await User.findOne({ where: { uuid: uuid } }))) {
		throw error(
			400,
			'Dein Minecraft-Account wurde bereits registriert.\n\nKontaktiere bitte einen Admin, falls diese ' +
				'Informationen für Dich fehlerhaft erscheinen oder Du Angaben Deiner bestehenden Registrierung verändern ' +
				'möchtest.'
		);
	} else if (
		await User.findOne({
			where: {
				firstname: data.firstname,
				lastname: data.lastname,
				birthday: data.birthday.toUTCString()
			}
		})
	) {
		throw error(
			400,
			'In Deinem Namen wurde bereits ein Minecraft-Account registriert. Es ist nur ein Account pro Spieler ' +
				'erlaubt.\n\nKontaktiere bitte einen Admin, falls diese Informationen für Dich fehlerhaft erscheinen oder ' +
				'Du Angaben Deiner bestehenden Registrierung verändern möchtest.'
		);
	}

	await User.create({
		firstname: data.firstname,
		lastname: data.lastname,
		birthday: data.birthday.toUTCString(),
		telephone: data.telephone,
		username: data.username,
		playertype: data.playertype,
		password: null,
		uuid: uuid
	});

	return new Response();
}) satisfies RequestHandler;
